## $Id: utils.py 11827 2014-10-02 12:12:32Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""General helper functions and utilities for the application section.
"""

from kofacustom.nigeria.applicants.utils import NigeriaApplicantsUtils
from waeup.kofa.applicants.workflow import (INITIALIZED,
    STARTED, PAID, ADMITTED, NOT_ADMITTED, SUBMITTED, CREATED)
from waeup.uniben.interfaces import MessageFactory as _



class CustomApplicantsUtils(NigeriaApplicantsUtils):
    """A collection of parameters and methods subject to customization.
    """

    APP_TYPES_DICT = {
        'pude': ['Post-UDE Screening', 'PUDE'],
        'prence': ['Pre-NCE Programme', 'PRE'],
        'sandwich': ['Part-Time Degree in Education', 'SAND'],
        'pt': ['Part-Time Degree Programmes', 'PTP'],
        'ptext': ['Part-Time Degree Programmes (extended application)', 'PTP'],
        'putme': ['Post-UTME Screening Exercise', 'PUTME'],
        'app': ['General Studies', 'APP'],
        'cest': ['Common Entry Screening Test', 'CEST'],
        'ct': ['Certificate Programmes', 'CTP'],
        'dp': ['Diploma Programmes', 'DPP'],
        'dpft': ['Diploma Full-Time Programmes', 'DPP'],
        'pce': ['PCE Screening', 'PCE'],
        'pg': ['Postgraduate Programmes', 'PG'],
        'pgft': ['Postgraduate Full-Time Programmes', 'PG'],
        'pgpt': ['Postgraduate Part-Time Programmes', 'PG'],
        'pgnew': ['New Postgraduate Programmes', 'NEWPG'],
        'pgext': ['Postgraduate Programmes (extended application)', 'PG']
        }


    # Temporarily disabled
    def xxx_getApplicantsStatistics(self, container):
        state_stats = {INITIALIZED:0, STARTED:0, PAID:0, SUBMITTED:0,
            ADMITTED:0, NOT_ADMITTED:0, CREATED:0}
        faculty_keys = grok.getSite()['faculties'].keys()
        fac_stats = dict([(i,0) for i in faculty_keys])
        for key in container.keys():
            state = container[key].state
            state_stats[state] += 1
            cert = getattr(container[key],'course1',None)
            if  cert is not None and state == SUBMITTED:
                faculty = cert.__parent__.__parent__.__parent__
                fac_stats[faculty.__name__] += 1
        return state_stats, fac_stats
